==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_bservice_list/main.tf <==
/*
Пример использования
Получение списка доступных базовых сервисов

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_bservice_list" "bsl" {
  #фильтр по id базового сервиса
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени базового сервиса
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для фильтрации данных
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.decort_bservice_list.bsl
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_bservice_list/main.tf <==
/*
Пример использования
Получение списка доступных базовых сервисов

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_bservice_list" "bsl" {
  #фильтр по id базового сервиса
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени базового сервиса
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для фильтрации данных
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.decort_bservice_list.bsl
}
